@@ -14,8 +14,8 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
+ * License along with this library. If not, see
+ * <http://www.gnu.org/licenses/>.
  *
  * Author: Marc-André Lureau <marcandre.lureau@redhat.com>
  */
@@ -49,27 +49,13 @@ gvir_domain_disk_error_quark(void)
     return g_quark_from_static_string("gvir-domain-disk");
 }
 
-static void gvir_domain_disk_finalize(GObject *object)
-{
-    GVirDomainDisk *self = GVIR_DOMAIN_DISK(object);
-
-    g_debug("Finalize GVirDomainDisk=%p", self);
-
-    G_OBJECT_CLASS(gvir_domain_disk_parent_class)->finalize(object);
-}
-
 static void gvir_domain_disk_class_init(GVirDomainDiskClass *klass)
 {
-    GObjectClass *object_class = G_OBJECT_CLASS (klass);
-
-    object_class->finalize = gvir_domain_disk_finalize;
     g_type_class_add_private(klass, sizeof(GVirDomainDiskPrivate));
 }
 
 static void gvir_domain_disk_init(GVirDomainDisk *self)
 {
-    g_debug("Init GVirDomainDisk=%p", self);
-
     self->priv = GVIR_DOMAIN_DISK_GET_PRIVATE(self);
 }
 
