@@ -63,8 +63,6 @@ static void gvir_manager_finalize(GObject *object)
     GVirManager *man = GVIR_MANAGER(object);
     GVirManagerPrivate *priv = man->priv;
 
-    g_debug("Finalize GVirManager=%p", man);
-
     GList *tmp = priv->connections;
     while (tmp) {
         GVirConnection *conn = tmp->data;
@@ -112,8 +110,6 @@ static void gvir_manager_init(GVirManager *manager)
 {
     GVirManagerPrivate *priv;
 
-    g_debug("Init GVirManager=%p", manager);
-
     priv = manager->priv = GVIR_MANAGER_GET_PRIVATE(manager);
 
     priv->lock = g_mutex_new();
