@@ -30,12 +30,11 @@
     g_free(alloced_str); \
 } G_STMT_END
 
-static void check_xml(GVirConfigDomain *domain, const char *reference_file)
+static char * load_xml(const char *reference_file)
 {
     const char *reference_path;
     GError *error = NULL;
     char *reference_xml;
-    char *xml;
 
     reference_path = g_test_get_filename(G_TEST_DIST, "xml",
                                          reference_file, NULL);
@@ -45,6 +44,18 @@ static void check_xml(GVirConfigDomain *domain, const char *reference_file)
      * gedit, workaround this issue by removing trailing whitespace from
      * the reference file */
     g_strchomp(reference_xml);
+
+    return reference_xml;
+}
+
+
+static void check_xml(GVirConfigDomain *domain, const char *reference_file)
+{
+    char *reference_xml;
+    char *xml;
+
+    reference_xml = load_xml(reference_file);
+
     xml = gvir_config_object_to_xml(GVIR_CONFIG_OBJECT(domain));
     g_assert_cmpstr(xml, ==, reference_xml);
     g_free(xml);
@@ -709,6 +720,71 @@ static void test_domain_device_usb_redir(void)
     g_object_unref(G_OBJECT(domain));
 }
 
+static void test_domain_device_pci_hostdev(void)
+{
+    GVirConfigDomain *domain;
+    GVirConfigDomainAddressPci *address;
+    GVirConfigDomainHostdevPci *hostdev;
+
+    domain = gvir_config_domain_new();
+
+    hostdev = gvir_config_domain_hostdev_pci_new();
+    gvir_config_domain_hostdev_set_boot_order(GVIR_CONFIG_DOMAIN_HOSTDEV(hostdev), 1);
+    g_assert_cmpint(gvir_config_domain_hostdev_get_boot_order(GVIR_CONFIG_DOMAIN_HOSTDEV(hostdev)), ==, 1);
+    gvir_config_domain_hostdev_pci_set_managed(hostdev, TRUE);
+    g_assert(gvir_config_domain_hostdev_pci_get_managed(hostdev) == TRUE);
+    gvir_config_domain_hostdev_pci_set_rom_bar(hostdev, TRUE);
+    gvir_config_domain_hostdev_pci_set_rom_file(hostdev, "/etc/fake/boot.bin");
+    g_assert_cmpstr(gvir_config_domain_hostdev_pci_get_rom_file(hostdev), ==, "/etc/fake/boot.bin");
+    g_assert(gvir_config_domain_hostdev_pci_get_rom_bar(hostdev));
+
+    address = gvir_config_domain_address_pci_new();
+    gvir_config_domain_address_pci_set_domain(address, 1);
+    gvir_config_domain_address_pci_set_bus(address, 2);
+    gvir_config_domain_address_pci_set_slot(address, 3);
+    gvir_config_domain_address_pci_set_function(address, 4);
+    gvir_config_domain_hostdev_pci_set_address(hostdev, address);
+    g_object_unref(G_OBJECT(address));
+
+    address = gvir_config_domain_hostdev_pci_get_address(hostdev);
+    g_assert(address != NULL);
+    g_assert_cmpint(gvir_config_domain_address_pci_get_domain(address), ==, 1);
+    g_assert_cmpint(gvir_config_domain_address_pci_get_bus(address), ==, 2);
+    g_assert_cmpint(gvir_config_domain_address_pci_get_slot(address), ==, 3);
+    g_assert_cmpint(gvir_config_domain_address_pci_get_function(address), ==, 4);
+    g_object_unref(G_OBJECT(address));
+
+    gvir_config_domain_add_device(domain, GVIR_CONFIG_DOMAIN_DEVICE (hostdev));
+    g_object_unref(G_OBJECT(hostdev));
+
+    check_xml(domain, "gconfig-domain-device-pci-hostdev.xml");
+
+    g_object_unref(G_OBJECT(domain));
+}
+
+static void test_domain_device_unknown(void)
+{
+    GVirConfigDomain *domain;
+    GList *devices;
+    GError *error = NULL;
+    char *xml;
+
+    xml = load_xml("gconfig-domain-device-unknown.xml");
+
+    domain = gvir_config_domain_new_from_xml(xml, &error);
+    g_assert_no_error(error);
+
+    devices = gvir_config_domain_get_devices(domain);
+    g_assert_nonnull(devices);
+    gvir_config_domain_set_devices(domain, devices);
+
+    check_xml(domain, "gconfig-domain-device-unknown.xml");
+
+    g_list_free_full(devices, g_object_unref);
+    g_object_unref(G_OBJECT(domain));
+    g_free(xml);
+}
+
 
 int main(int argc, char **argv)
 {
@@ -739,6 +815,10 @@ int main(int argc, char **argv)
                     test_domain_device_channel);
     g_test_add_func("/libvirt-gconfig/domain-device-usb-redir",
                     test_domain_device_usb_redir);
+    g_test_add_func("/libvirt-gconfig/domain-device-pci-hostdev",
+                    test_domain_device_pci_hostdev);
+    g_test_add_func("/libvirt-gconfig/domain-device-unknown",
+                    test_domain_device_unknown);
 
     return g_test_run();
 }
